<?php
/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since 1.0.0.37
 * @access public
 */
final class Zoom_Lite_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since 1.0.0.37
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since 1.0.0.37
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since 1.0.0.37
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'zoom_lite_info_sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'zoom_lite_enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since 1.0.0.37
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function zoom_lite_info_sections( $manager ) {

		// Load custom sections.
		require_once( trailingslashit( get_template_directory() ) . 'inc/customizer/info/info-cnt.php' );

		// Register custom section types.
		$manager->register_section_type( 'Zoom_Lite_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(
			new Zoom_Lite_Customize_Section_Pro(
				$manager,
				'zoom_lite_info',
				array(
					'title'    => esc_html__( 'Love this Theme?', 'zoom-lite' ),
					'pro_text' => esc_html__( 'Write a Review', 'zoom-lite' ),
					'pro_url'  => esc_url( 'https://wordpress.org/support/theme/zoom-lite/reviews/?filter=5#new-post' )
				)
			)
		);
	}
	

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since 1.0.0.37
	 * @access public
	 * @return void
	 */
	public function zoom_lite_enqueue_control_scripts() {

		wp_enqueue_script( 'zoom-lite-info-customize-controls', trailingslashit( get_template_directory_uri() ) . 'inc/customizer/info/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'zoom-lite-info-customize-controls', trailingslashit( get_template_directory_uri() ) . 'inc/customizer/info/customize-controls.css' );
	}
}

// Doing this customizer!
Zoom_Lite_Customize::get_instance();
